Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Acquire ¶
Acquire acquires a lock on a resource for the given agent. Convenience wrapper around Global().Acquire().
func Global ¶
func Global() *muxcoord.Coordinator
Global returns the singleton coordinator instance. Thread-safe via sync.Once.
func Release ¶
Release releases a lock on a resource. Convenience wrapper around Global().Release().
func ReleaseAll ¶
func ReleaseAll(agentID string)
ReleaseAll releases all locks held by the given agent. Convenience wrapper around Global().ReleaseAll().
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.